# _G

Extends Lua's _G table to provide extra functions and fields.

- - -

## Fields

- - -

<a id="OSX"></a>
### `OSX` (bool)

If Textadept is running on Mac OSX, this flag is `true`.

- - -

<a id="RESETTING"></a>
### `RESETTING` (bool)

If [`reset()`](#reset) has been called, this flag is `true` while the Lua
  state is being re-initialized.

- - -

<a id="WIN32"></a>
### `WIN32` (bool)

If Textadept is running on Windows, this flag is `true`.

- - -

<a id="_CHARSET"></a>
### `_CHARSET` (string)

The character set encoding of the filesystem.
  This is used in [File I/O](io.html).

- - -

<a id="_HOME"></a>
### `_HOME` (string)

Path to the directory containing Textadept.

- - -

<a id="_LEXERPATH"></a>
### `_LEXERPATH` (string)

Paths to lexers, formatted like
  [`package.path`](http://lua.org/manual/5.2/manual.html#pdf-package.path).

- - -

<a id="_RELEASE"></a>
### `_RELEASE` (string)

The Textadept release version.

- - -

<a id="_USERHOME"></a>
### `_USERHOME` (string)

Path to the user's `~/.textadept/`.

- - -


## Functions

- - -

<a id="new_buffer"></a>
### `new_buffer` ()

Creates a new buffer.
Generates a `BUFFER_NEW` event.

Return:

* the new buffer.

- - -

<a id="quit"></a>
### `quit` ()

Quits Textadept.

- - -

<a id="reset"></a>
### `reset` ()

Resets the Lua state by reloading all init scripts.
Language-specific modules for opened files are NOT reloaded. Re-opening the
files that use them will reload those modules.
This function is useful for modifying init scripts (such as the user's
`modules/textadept/keys.lua`) on the fly without having to restart Textadept.
`_G.RESETTING` is set to `true` when re-initing the Lua State. Any scripts
that need to differentiate between startup and reset can utilize this
variable.

See also:

* [`RESETTING`](#RESETTING)

- - -

<a id="timeout"></a>
### `timeout` (interval, f, ...)

Calls a given function after an interval of time.
To repeatedly call the function, return true inside the function. A `nil` or
`false` return value stops repetition.

Parameters:

* `interval`: The interval in seconds to call the function after.
* `f`: The function to call.
* `...`: Additional arguments to pass to `f`.

- - -

<a id="user_dofile"></a>
### `user_dofile` (filename)

Calls `dofile()` on the given filename in the user's Textadept directory.
Errors are printed to the Textadept message buffer.

Parameters:

* `filename`: The name of the file (not path).

Return:

* `true` if successful; `false` otherwise.

See also:

* [`dofile`](#dofile)

- - -


## Tables

- - -

<a id="_BUFFERS"></a>
### `_BUFFERS`

Table of all open buffers in Textadept.
Numeric keys have buffer values and buffer keys have their associated numeric
keys.

Usage:

* `_BUFFERS[1] contains the first buffer.`
* `_BUFFERS[buffer] returns the index of the current buffer in _BUFFERS.`

- - -

<a id="_VIEWS"></a>
### `_VIEWS`

Table of all views in Textadept.
Numeric keys have view values and view keys have their associated numeric
keys.

Usage:

* `_VIEWS[1] contains the first view.`
* `_VIEWS[view] returns the index of the current view in _VIEWS.`

- - -

<a id="arg"></a>
### `arg`

Command line parameters.

- - -

